@@ -94,7 +94,7 @@ class ARIMA(TransferableDualCovariatesForecastingModel):
     ) -> TimeSeries:
 
         if num_samples > 1 and self.trend:
-            logger.warn(
+            logger.warning(
                 "Trends are not well supported yet for getting probabilistic forecasts with ARIMA."
                 "If you run into issues, try calling fit() with num_samples=1 or removing the trend from"
                 "your model."
