@@ -130,7 +130,7 @@ class BlockRNNModel(PastCovariatesTorchModel):
         input_chunk_length: int,
         output_chunk_length: int,
         model: Union[str, nn.Module] = "RNN",
-        hidden_size: int = 25,
+        hidden_dim: int = 25,
         n_rnn_layers: int = 1,
         hidden_fc_sizes: Optional[List] = None,
         dropout: float = 0.0,
@@ -162,8 +162,9 @@ class BlockRNNModel(PastCovariatesTorchModel):
             Either a string specifying the RNN module type ("RNN", "LSTM" or "GRU"),
             or a PyTorch module with the same specifications as
             :class:`darts.models.block_rnn_model._BlockRNNModule`.
-        hidden_size
+        hidden_dim
             Size for feature maps for each hidden RNN layer (:math:`h_n`).
+            In Darts version <= 0.21, hidden_dim was referred as hidden_size.
         n_rnn_layers
             Number of layers in the RNN module.
         hidden_fc_sizes
@@ -214,24 +215,6 @@ class BlockRNNModel(PastCovariatesTorchModel):
         nr_epochs_val_period
             Number of epochs to wait before evaluating the validation loss (if a validation
             ``TimeSeries`` is passed to the :func:`fit()` method). Default: ``1``.
-        torch_device_str
-            Optionally, a string indicating the torch device to use. By default, ``torch_device_str`` is ``None``
-            which will run on CPU. Set it to ``"cuda"`` to use all available GPUs or ``"cuda:i"`` to only use
-            GPU ``i`` (``i`` must be an integer). For example "cuda:0" will use the first GPU only.
-
-            .. deprecated:: v0.17.0
-                ``torch_device_str`` has been deprecated in v0.17.0 and will be removed in a future version.
-                Instead, specify this with keys ``"accelerator", "gpus", "auto_select_gpus"`` in your
-                ``pl_trainer_kwargs`` dict. Some examples for setting the devices inside the ``pl_trainer_kwargs``
-                dict:
-
-                - ``{"accelerator": "cpu"}`` for CPU,
-                - ``{"accelerator": "gpu", "gpus": [i]}`` to use only GPU ``i`` (``i`` must be an integer),
-                - ``{"accelerator": "gpu", "gpus": -1, "auto_select_gpus": True}`` to use all available GPUS.
-
-                For more info, see here:
-                https://pytorch-lightning.readthedocs.io/en/stable/common/trainer.html#trainer-flags , and
-                https://pytorch-lightning.readthedocs.io/en/stable/advanced/multi_gpu.html#select-gpu-devices
         force_reset
             If set to ``True``, any previously-existing model with the same name will be reset (all checkpoints will
             be discarded). Default: ``False``.
@@ -256,7 +239,7 @@ class BlockRNNModel(PastCovariatesTorchModel):
                 add_encoders={
                     'cyclic': {'future': ['month']},
                     'datetime_attribute': {'future': ['hour', 'dayofweek']},
-                    'position': {'past': ['absolute'], 'future': ['relative']},
+                    'position': {'past': ['relative'], 'future': ['relative']},
                     'custom': {'past': [lambda idx: (idx.year - 1950) / 50]},
                     'transformer': Scaler()
                 }
@@ -273,6 +256,19 @@ class BlockRNNModel(PastCovariatesTorchModel):
             object. Check the `PL Trainer documentation
             <https://pytorch-lightning.readthedocs.io/en/stable/common/trainer.html>`_ for more information about the
             supported kwargs. Default: ``None``.
+            Running on GPU(s) is also possible using ``pl_trainer_kwargs`` by specifying keys ``"accelerator",
+            "devices", and "auto_select_gpus"``. Some examples for setting the devices inside the ``pl_trainer_kwargs``
+            dict:
+
+
+            - ``{"accelerator": "cpu"}`` for CPU,
+            - ``{"accelerator": "gpu", "devices": [i]}`` to use only GPU ``i`` (``i`` must be an integer),
+            - ``{"accelerator": "gpu", "devices": -1, "auto_select_gpus": True}`` to use all available GPUS.
+
+            For more info, see here:
+            https://pytorch-lightning.readthedocs.io/en/stable/common/trainer.html#trainer-flags , and
+            https://pytorch-lightning.readthedocs.io/en/stable/accelerators/gpu_basic.html#train-on-multiple-gpus
+
             With parameter ``"callbacks"`` you can add custom or PyTorch-Lightning built-in callbacks to Darts'
             :class:`TorchForecastingModel`. Below is an example for adding EarlyStopping to the training process.
             The model will stop training early if the validation loss `val_loss` does not improve beyond
@@ -321,7 +317,7 @@ class BlockRNNModel(PastCovariatesTorchModel):
 
         self.rnn_type_or_module = model
         self.hidden_fc_sizes = hidden_fc_sizes
-        self.hidden_size = hidden_size
+        self.hidden_dim = hidden_dim
         self.n_rnn_layers = n_rnn_layers
         self.dropout = dropout
 
@@ -346,7 +342,7 @@ class BlockRNNModel(PastCovariatesTorchModel):
                 input_size=input_dim,
                 target_size=output_dim,
                 nr_params=nr_params,
-                hidden_dim=self.hidden_size,
+                hidden_dim=self.hidden_dim,
                 num_layers=self.n_rnn_layers,
                 num_layers_out_fc=hidden_fc_sizes,
                 dropout=self.dropout,
