@@ -33,6 +33,7 @@ from darts.utils import (
     _build_tqdm_iterator,
     _historical_forecasts_general_checks,
     _parallel_apply,
+    _retrain_wrapper,
     _with_sanity_checks,
 )
 from darts.utils.data.encoders import SequentialEncoder
@@ -148,7 +149,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
 
     def _supports_range_index(self) -> bool:
         """Checks if the forecasting model supports a range index.
-        Some models may not support this, if for instance the rely on underlying dates.
+        Some models may not support this, if for instance they rely on underlying dates.
 
         By default, returns True. Needs to be overwritten by models that do not support
         range indexing and raise meaningful exception.
@@ -273,7 +274,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         args
             The args parameter(s) provided to the historical_forecasts function.
         kwargs
-            The kwargs paramter(s) provided to the historical_forecasts function.
+            The kwargs parameter(s) provided to the historical_forecasts function.
 
         Raises
         ------
@@ -303,7 +304,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         start: Union[pd.Timestamp, float, int] = 0.5,
         forecast_horizon: int = 1,
         stride: int = 1,
-        retrain: bool = True,
+        retrain: Union[bool, int, Callable[..., bool]] = True,
         overlap_end: bool = False,
         last_points_only: bool = True,
         verbose: bool = False,
@@ -357,8 +358,22 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         stride
             The number of time steps between two consecutive predictions.
         retrain
-            Whether to retrain the model for every prediction or not. Not all models support setting
-            `retrain` to `False`. Notably, this is supported by neural networks based models.
+            Whether and/or on which condition to retrain the model before predicting.
+            This parameter supports 3 different datatypes: ``bool``, (positive) ``int``, and
+            ``Callable`` (returning a ``bool``).
+            In the case of ``bool``: retrain the model at each step (`True`), or never retrains the model (`False`).
+            In the case of ``int``: the model is retrained every `retrain` iterations.
+            In the case of ``Callable``: the model is retrained whenever callable returns `True`.
+            Arguments passed to the callable are as follows:
+
+                - `pred_time (pd.Timestamp or int)`: timestamp of forecast time (end of the training series)
+                - `train_series (TimeSeries)`: train series up to `pred_time`
+                - `past_covariates (TimeSeries)`: past_covariates series up to `pred_time`
+                - `future_covariates (TimeSeries)`: future_covariates series up
+                  to `min(pred_time + series.freq * forecast_horizon, series.end_time())`
+
+            Note: some models do require being retrained every time
+            and do not support anything else than `retrain=True`.
         overlap_end
             Whether the returned forecasts can go beyond the series' end or not
         last_points_only
@@ -384,10 +399,11 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         # only GlobalForecastingModels support historical forecastings without retraining the model
         base_class_name = self.__class__.__base__.__name__
         raise_if(
-            not retrain and not self._supports_non_retrainable_historical_forecasts(),
+            (isinstance(retrain, Callable) or int(retrain) != 1)
+            and (not self._supports_non_retrainable_historical_forecasts()),
             f"{base_class_name} does not support historical forecastings with `retrain` set to `False`. "
             f"For now, this is only supported with GlobalForecastingModels such as TorchForecastingModels. "
-            f"Fore more information, read the documentation for `retrain` in `historical_forecastings()`",
+            f"For more information, read the documentation for `retrain` in `historical_forecasts()`",
             logger,
         )
 
@@ -409,6 +425,25 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
                 logger,
             )
 
+        if isinstance(retrain, bool) or (isinstance(retrain, int) and retrain >= 0):
+            retrain_func = _retrain_wrapper(
+                lambda counter: counter % int(retrain) == 0 if retrain else False
+            )
+
+        elif isinstance(retrain, Callable):
+            retrain_func = _retrain_wrapper(retrain)
+
+        else:
+            raise_log(
+                ValueError(
+                    "`retrain` argument must be either `bool`, positive `int` or `Callable` (returning `bool`)"
+                ),
+                logger,
+            )
+        retrain_func_signature = tuple(
+            inspect.signature(retrain_func).parameters.keys()
+        )
+
         # prepare the start parameter -> pd.Timestamp
         start = series.get_timestamp_at_point(start)
 
@@ -435,7 +470,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         last_points_values = []
 
         # iterate and forecast
-        for pred_time in iterator:
+        for _counter, pred_time in enumerate(iterator):
             # build the training series
             train = series.drop_after(pred_time)
             if train_length and len(train) > train_length:
@@ -443,7 +478,19 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
 
             # train_cov = covariates.drop_after(pred_time) if covariates else None
 
-            if retrain or not self._fit_called:
+            if (not self._fit_called) or retrain_func(
+                counter=_counter,
+                pred_time=pred_time,
+                train_series=train,
+                past_covariates=past_covariates.drop_after(pred_time)
+                if past_covariates and ("past_covariates" in retrain_func_signature)
+                else None,
+                future_covariates=future_covariates.drop_after(
+                    min(pred_time + series.freq * forecast_horizon, series.end_time())
+                )
+                if future_covariates and ("future_covariates" in retrain_func_signature)
+                else None,
+            ):
                 self._fit_wrapper(
                     series=train,
                     past_covariates=past_covariates,
@@ -478,7 +525,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
                     pd.RangeIndex(
                         start=last_points_times[0],
                         stop=last_points_times[-1] + 1,
-                        step=1,
+                        step=series.freq * stride,
                     ),
                     np.array(last_points_values),
                     columns=series.columns,
@@ -498,7 +545,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         start: Union[pd.Timestamp, float, int] = 0.5,
         forecast_horizon: int = 1,
         stride: int = 1,
-        retrain: bool = True,
+        retrain: Union[bool, int, Callable[..., bool]] = True,
         overlap_end: bool = False,
         last_points_only: bool = False,
         metric: Callable[[TimeSeries, TimeSeries], float] = metrics.mape,
@@ -556,8 +603,22 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         stride
             The number of time steps between two consecutive training sets.
         retrain
-            Whether to retrain the model for every prediction or not. Not all models support setting
-            `retrain` to `False`. Notably, this is supported by neural networks based models.
+            Whether and/or on which condition to retrain the model before predicting.
+            This parameter supports 3 different datatypes: ``bool``, (positive) ``int``, and
+            ``Callable`` (returning a ``bool``).
+            In the case of ``bool``: retrain the model at each step (`True`), or never retrains the model (`False`).
+            In the case of ``int``: the model is retrained every `retrain` iterations.
+            In the case of ``Callable``: the model is retrained whenever callable returns `True`.
+            Arguments passed to the callable are as follows:
+
+                - `pred_time (pd.Timestamp or int)`: timestamp of forecast time (end of the training series)
+                - `train_series (TimeSeries)`: train series up to `pred_time`
+                - `past_covariates (TimeSeries)`: past_covariates series up to `pred_time`
+                - `future_covariates (TimeSeries)`: future_covariates series up
+                  to `min(pred_time + series.freq * forecast_horizon, series.end_time())`
+
+            Note: some models do require being retrained every time
+            and do not support anything else than `retrain=True`.
         overlap_end
             Whether the returned forecasts can go beyond the series' end or not
         last_points_only
@@ -566,7 +627,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
             A function that takes two ``TimeSeries`` instances as inputs and returns an error value.
         reduction
             A function used to combine the individual error scores obtained when `last_points_only` is set to False.
-            If explicitely set to `None`, the method will return a list of the individual error scores instead.
+            If explicitly set to `None`, the method will return a list of the individual error scores instead.
             Set to ``np.mean`` by default.
         verbose
             Whether to print progress
@@ -817,6 +878,8 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
     def residuals(
         self,
         series: TimeSeries,
+        past_covariates: Optional[TimeSeries] = None,
+        future_covariates: Optional[TimeSeries] = None,
         forecast_horizon: int = 1,
         retrain: bool = True,
         verbose: bool = False,
@@ -833,13 +896,17 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         Most commonly, the term "residuals" implies a value for `forecast_horizon` of 1; but
         this can be configured.
 
-        This method works only on univariate series and does not currently support covariates. It uses the median
+        This method works only on univariate series. It uses the median
         prediction (when dealing with stochastic forecasts).
 
         Parameters
         ----------
         series
             The univariate TimeSeries instance which the residuals will be computed for.
+        past_covariates
+            One or several past-observed covariate time series.
+        future_covariates
+            One or several future-known covariate time series.
         forecast_horizon
             The forecasting horizon used to predict each fitted value.
         retrain
@@ -852,7 +919,25 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         TimeSeries
             The vector of residuals.
         """
-        series._assert_univariate()
+        try:
+            series._assert_univariate()
+        except (AttributeError, TypeError):
+            raise ValueError(
+                "series must be of type TimeSeries. "
+                "If Sequence[TimeSeries] is provided, select the series to compute residuals for."
+            )
+
+        if past_covariates is not None:
+            raise_if_not(
+                isinstance(past_covariates, TimeSeries),
+                "past_covariates should be of type TimeSeries",
+            )
+
+        if future_covariates is not None:
+            raise_if_not(
+                isinstance(future_covariates, TimeSeries),
+                "future_covariates should be of type TimeSeries",
+            )
 
         # get first index not contained in the first training set
         first_index = series.time_index[self.min_train_series_length]
@@ -860,6 +945,8 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         # compute fitted values
         p = self.historical_forecasts(
             series=series,
+            past_covariates=past_covariates,
+            future_covariates=future_covariates,
             start=first_index,
             forecast_horizon=forecast_horizon,
             stride=1,
@@ -1191,6 +1278,98 @@ class GlobalForecastingModel(ForecastingModel, ABC):
             takes_future_covariates=takes_future_covariates,
         )
 
+    def generate_fit_encodings(
+        self,
+        series: Union[TimeSeries, Sequence[TimeSeries]],
+        past_covariates: Optional[Union[TimeSeries, Sequence[TimeSeries]]] = None,
+        future_covariates: Optional[Union[TimeSeries, Sequence[TimeSeries]]] = None,
+    ) -> Tuple[
+        Union[TimeSeries, Sequence[TimeSeries]], Union[TimeSeries, Sequence[TimeSeries]]
+    ]:
+        """Generates the covariate encodings that were used/generated for fitting the model and returns a tuple of
+        past, and future covariates series with the original and encoded covariates stacked together. The encodings are
+        generated by the encoders defined at model creation with parameter `add_encoders`. Pass the same `series`,
+        `past_covariates`, and  `future_covariates` that you used to train/fit the model.
+
+        Parameters
+        ----------
+        series
+            The series or sequence of series with the target values used when fitting the model.
+        past_covariates
+            Optionally, the series or sequence of series with the past-observed covariates used when fitting the model.
+        future_covariates
+            Optionally, the series or sequence of series with the future-known covariates used when fitting the model.
+
+        Returns
+        -------
+        Tuple[Union[TimeSeries, Sequence[TimeSeries]], Union[TimeSeries, Sequence[TimeSeries]]]
+            A tuple of (past covariates, future covariates). Each covariate contains the original as well as the
+            encoded covariates.
+        """
+        raise_if(
+            self.encoders is None or not self.encoders.encoding_available,
+            "Encodings are not available. Consider adding parameter `add_encoders` at model creation and fitting the "
+            "model with `model.fit()` before.",
+            logger=logger,
+        )
+        return self.encoders.encode_train(
+            target=series,
+            past_covariate=past_covariates,
+            future_covariate=future_covariates,
+        )
+
+    def generate_predict_encodings(
+        self,
+        n: int,
+        series: Union[TimeSeries, Sequence[TimeSeries]],
+        past_covariates: Optional[Union[TimeSeries, Sequence[TimeSeries]]] = None,
+        future_covariates: Optional[Union[TimeSeries, Sequence[TimeSeries]]] = None,
+    ) -> Tuple[
+        Union[TimeSeries, Sequence[TimeSeries]], Union[TimeSeries, Sequence[TimeSeries]]
+    ]:
+        """Generates covariate encodings for the inference/prediction set and returns a tuple of past, and future
+        covariates series with the original and encoded covariates stacked together. The encodings are generated by the
+        encoders defined at model creation with parameter `add_encoders`. Pass the same `series`, `past_covariates`,
+        and `future_covariates` that you intend to use for prediction.
+
+        Parameters
+        ----------
+        n
+            The number of prediction time steps after the end of `series` intended to be used for prediction.
+        series
+            The series or sequence of series with target values intended to be used for prediction.
+        past_covariates
+            Optionally, the past-observed covariates series intended to be used for prediction. The dimensions must
+            match those of the covariates used for training.
+        future_covariates
+            Optionally, the future-known covariates series intended to be used for prediction. The dimensions must
+            match those of the covariates used for training.
+
+        Returns
+        -------
+        Tuple[Union[TimeSeries, Sequence[TimeSeries]], Union[TimeSeries, Sequence[TimeSeries]]]
+            A tuple of (past covariates, future covariates). Each covariate contains the original as well as the
+            encoded covariates.
+        """
+        raise_if(
+            self.encoders is None or not self.encoders.encoding_available,
+            "Encodings are not available. Consider adding parameter `add_encoders` at model creation and fitting the "
+            "model with `model.fit()` before.",
+            logger=logger,
+        )
+        return self.encoders.encode_inference(
+            n=self._get_encoders_n(n),
+            target=series,
+            past_covariate=past_covariates,
+            future_covariate=future_covariates,
+        )
+
+    def _get_encoders_n(self, n) -> int:
+        """Returns the number of prediction steps for generating with `model.encoders.generate_predict_encodings()`.
+        Subclasses can have different requirements for setting `n`. The most general case simply returns `n` as is.
+        """
+        return n
+
 
 class DualCovariatesForecastingModel(ForecastingModel, ABC):
     """The base class for the forecasting models that are not global, but support future covariates.
