@@ -72,6 +72,7 @@ from darts.utils.data.training_dataset import (
 )
 from darts.utils.likelihood_models import Likelihood
 from darts.utils.torch import random_method
+from darts.utils.utils import seq2series, series2seq
 
 DEFAULT_DARTS_FOLDER = "darts_logs"
 CHECKPOINTS_FOLDER = "checkpoints"
@@ -122,7 +123,6 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
         work_dir: str = os.path.join(os.getcwd(), DEFAULT_DARTS_FOLDER),
         log_tensorboard: bool = False,
         nr_epochs_val_period: int = 1,
-        torch_device_str: Optional[str] = None,
         force_reset: bool = False,
         save_checkpoints: bool = False,
         add_encoders: Optional[dict] = None,
@@ -163,24 +163,6 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
         nr_epochs_val_period
             Number of epochs to wait before evaluating the validation loss (if a validation
             ``TimeSeries`` is passed to the :func:`fit()` method). Default: ``1``.
-        torch_device_str
-            Optionally, a string indicating the torch device to use. By default, ``torch_device_str`` is ``None``
-            which will run on CPU. Set it to ``"cuda"`` to use all available GPUs or ``"cuda:i"`` to only use
-            GPU ``i`` (``i`` must be an integer). For example "cuda:0" will use the first GPU only.
-
-            .. deprecated:: v0.17.0
-                ``torch_device_str`` has been deprecated in v0.17.0 and will be removed in a future version.
-                Instead, specify this with keys ``"accelerator", "gpus", "auto_select_gpus"`` in your
-                ``pl_trainer_kwargs`` dict. Some examples for setting the devices inside the ``pl_trainer_kwargs``
-                dict:
-
-                - ``{"accelerator": "cpu"}`` for CPU,
-                - ``{"accelerator": "gpu", "gpus": [i]}`` to use only GPU ``i`` (``i`` must be an integer),
-                - ``{"accelerator": "gpu", "gpus": -1, "auto_select_gpus": True}`` to use all available GPUS.
-
-                For more info, see here:
-                https://pytorch-lightning.readthedocs.io/en/stable/common/trainer.html#trainer-flags , and
-                https://pytorch-lightning.readthedocs.io/en/stable/advanced/multi_gpu.html#select-gpu-devices
         force_reset
             If set to ``True``, any previously-existing model with the same name will be reset (all checkpoints will
             be discarded). Default: ``False``.
@@ -205,7 +187,7 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
                 add_encoders={
                     'cyclic': {'future': ['month']},
                     'datetime_attribute': {'future': ['hour', 'dayofweek']},
-                    'position': {'past': ['absolute'], 'future': ['relative']},
+                    'position': {'past': ['relative'], 'future': ['relative']},
                     'custom': {'past': [lambda idx: (idx.year - 1950) / 50]},
                     'transformer': Scaler()
                 }
@@ -222,6 +204,19 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
             object. Check the `PL Trainer documentation
             <https://pytorch-lightning.readthedocs.io/en/stable/common/trainer.html>`_ for more information about the
             supported kwargs. Default: ``None``.
+            Running on GPU(s) is also possible using ``pl_trainer_kwargs`` by specifying keys ``"accelerator",
+            "devices", and "auto_select_gpus"``. Some examples for setting the devices inside the ``pl_trainer_kwargs``
+            dict:
+
+
+            - ``{"accelerator": "cpu"}`` for CPU,
+            - ``{"accelerator": "gpu", "devices": [i]}`` to use only GPU ``i`` (``i`` must be an integer),
+            - ``{"accelerator": "gpu", "devices": -1, "auto_select_gpus": True}`` to use all available GPUS.
+
+            For more info, see here:
+            https://pytorch-lightning.readthedocs.io/en/stable/common/trainer.html#trainer-flags , and
+            https://pytorch-lightning.readthedocs.io/en/stable/accelerators/gpu_basic.html#train-on-multiple-gpus
+
             With parameter ``"callbacks"`` you can add custom or PyTorch-Lightning built-in callbacks to Darts'
             :class:`TorchForecastingModel`. Below is an example for adding EarlyStopping to the training process.
             The model will stop training early if the validation loss `val_loss` does not improve beyond
@@ -295,12 +290,6 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
         else:
             pass
 
-        # TODO: remove below in the next version ======>
-        accelerator, gpus, auto_select_gpus = self._extract_torch_devices(
-            torch_device_str
-        )
-        # TODO: until here <======
-
         # save best epoch on val_loss and last epoch under 'darts_logs/model_name/checkpoints/'
         if save_checkpoints:
             checkpoint_callback = pl.callbacks.ModelCheckpoint(
@@ -322,9 +311,6 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
 
         # setup trainer parameters from model creation parameters
         self.trainer_params = {
-            "accelerator": accelerator,
-            "gpus": gpus,
-            "auto_select_gpus": auto_select_gpus,
             "logger": model_logger,
             "max_epochs": n_epochs,
             "check_val_every_n_epoch": nr_epochs_val_period,
@@ -350,62 +336,6 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
         # pl_module_params must be set in __init__ method of TorchForecastingModel subclass
         self.pl_module_params: Optional[dict] = None
 
-    @staticmethod
-    def _extract_torch_devices(
-        torch_device_str,
-    ) -> Tuple[str, Optional[Union[list, int]], bool]:
-        """This method handles the deprecated `torch_device_str` and should be removed in a future Darts version.
-
-        Returns
-        -------
-        Tuple
-            (accelerator, gpus, auto_select_gpus)
-        """
-
-        if torch_device_str is None:
-            return "cpu", None, False
-
-        device_warning = (
-            "`torch_device_str` is deprecated and will be removed in a coming Darts version. For full support "
-            "of all torch devices, use PyTorch-Lightnings trainer flags and pass them inside "
-            "`pl_trainer_kwargs`. Flags of interest are {`accelerator`, `gpus`, `auto_select_gpus`, `devices`}. "
-            "For more information, visit "
-            "https://pytorch-lightning.readthedocs.io/en/stable/common/trainer.html#trainer-flags"
-        )
-        raise_deprecation_warning(device_warning, logger)
-        # check torch device
-        raise_if_not(
-            any(
-                [
-                    device_str in torch_device_str
-                    for device_str in ["cuda", "cpu", "auto"]
-                ]
-            ),
-            f"unknown torch_device_str `{torch_device_str}`. String must contain one of `('cuda', 'cpu', 'auto') "
-            + device_warning,
-            logger,
-        )
-        device_split = torch_device_str.split(":")
-
-        gpus = None
-        auto_select_gpus = False
-        accelerator = "gpu" if device_split[0] == "cuda" else device_split[0]
-
-        if len(device_split) == 2 and accelerator == "gpu":
-            gpus = device_split[1]
-            gpus = [int(gpus)]
-        elif len(device_split) == 1:
-            if accelerator == "gpu":
-                gpus = -1
-                auto_select_gpus = True
-        else:
-            raise_if(
-                True,
-                f"unknown torch_device_str `{torch_device_str}`. " + device_warning,
-                logger,
-            )
-        return accelerator, gpus, auto_select_gpus
-
     @classmethod
     def _validate_model_params(cls, **kwargs):
         """validate that parameters used at model creation are part of :class:`TorchForecastingModel`,
@@ -704,32 +634,44 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
         self
             Fitted model.
         """
-        super().fit(
-            series=series,
-            past_covariates=past_covariates,
-            future_covariates=future_covariates,
-        )
+        # guarantee that all inputs are either list of `TimeSeries` or `None`
+        series = series2seq(series)
+        past_covariates = series2seq(past_covariates)
+        future_covariates = series2seq(future_covariates)
+        val_series = series2seq(val_series)
+        val_past_covariates = series2seq(val_past_covariates)
+        val_future_covariates = series2seq(val_future_covariates)
+
+        self.encoders = self.initialize_encoders()
+        if self.encoders.encoding_available:
+            past_covariates, future_covariates = self.generate_fit_encodings(
+                series=series,
+                past_covariates=past_covariates,
+                future_covariates=future_covariates,
+            )
 
-        # TODO: also check the validation covariates
         self._verify_past_future_covariates(
             past_covariates=past_covariates, future_covariates=future_covariates
         )
         self._verify_static_covariates(series[0].static_covariates)
 
-        def wrap_fn(
-            ts: Union[TimeSeries, Sequence[TimeSeries]]
-        ) -> Sequence[TimeSeries]:
-            return [ts] if isinstance(ts, TimeSeries) else ts
-
-        series = wrap_fn(series)
-        past_covariates = wrap_fn(past_covariates)
-        future_covariates = wrap_fn(future_covariates)
-        val_series = wrap_fn(val_series)
-        val_past_covariates = wrap_fn(val_past_covariates)
-        val_future_covariates = wrap_fn(val_future_covariates)
-
         # Check that dimensions of train and val set match; on first series only
         if val_series is not None:
+            if self.encoders.encoding_available:
+                (
+                    val_past_covariates,
+                    val_future_covariates,
+                ) = self.generate_fit_encodings(
+                    series=val_series,
+                    past_covariates=val_past_covariates,
+                    future_covariates=val_future_covariates,
+                )
+            self._verify_past_future_covariates(
+                past_covariates=val_past_covariates,
+                future_covariates=val_future_covariates,
+            )
+            self._verify_static_covariates(val_series[0].static_covariates)
+
             match = (
                 series[0].width == val_series[0].width
                 and (past_covariates[0].width if past_covariates is not None else None)
@@ -755,14 +697,6 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
                 "and the validation set do not match.",
             )
 
-        self.encoders = self.initialize_encoders()
-
-        if self.encoders.encoding_available:
-            past_covariates, future_covariates = self.encoders.encode_train(
-                target=series,
-                past_covariate=past_covariates,
-                future_covariate=future_covariates,
-            )
         train_dataset = self._build_train_dataset(
             target=series,
             past_covariates=past_covariates,
@@ -771,13 +705,6 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
         )
 
         if val_series is not None:
-            if self.encoders.encoding_available:
-                val_past_covariates, val_future_covariates = self.encoders.encode_train(
-                    target=val_series,
-                    past_covariate=val_past_covariates,
-                    future_covariate=val_future_covariates,
-                )
-
             val_dataset = self._build_train_dataset(
                 target=val_series,
                 past_covariates=val_past_covariates,
@@ -803,6 +730,12 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
         )
         logger.info(f"Train dataset contains {len(train_dataset)} samples.")
 
+        super().fit(
+            series=seq2series(series),
+            past_covariates=seq2series(past_covariates),
+            future_covariates=seq2series(future_covariates),
+        )
+
         return self.fit_from_dataset(
             train_dataset, val_dataset, trainer, verbose, epochs, num_loader_workers
         )
@@ -949,7 +882,7 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
         # TODO: multiple training without loading from checkpoint is not trivial (I believe PyTorch-Lightning is still
         #  working on that, see https://github.com/PyTorchLightning/pytorch-lightning/issues/9636)
         if self.epochs_trained > 0 and not self.load_ckpt_path:
-            logger.warn(
+            logger.warning(
                 "Attempting to retrain the model without resuming from a checkpoint. This is currently "
                 "discouraged. Consider setting `save_checkpoints` to `True` and specifying `model_name` at model "
                 f"creation. Then call `model = {self.__class__.__name__}.load_from_checkpoint(model_name, "
@@ -1074,8 +1007,6 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
             One or several time series containing the forecasts of ``series``, or the forecast of the training series
             if ``series`` is not specified and the model has been trained on a single series.
         """
-        super().predict(n, series, past_covariates, future_covariates)
-
         if series is None:
             raise_if(
                 self.training_series is None,
@@ -1083,37 +1014,33 @@ class TorchForecastingModel(GlobalForecastingModel, ABC):
             )
             series = self.training_series
 
-        if past_covariates is None and self.past_covariate_series is not None:
-            past_covariates = self.past_covariate_series
-        if future_covariates is None and self.future_covariate_series is not None:
-            future_covariates = self.future_covariate_series
+        called_with_single_series = True if isinstance(series, TimeSeries) else False
 
-        called_with_single_series = False
-        if isinstance(series, TimeSeries):
-            called_with_single_series = True
-            series = [series]
-
-        past_covariates = (
-            [past_covariates]
-            if isinstance(past_covariates, TimeSeries)
-            else past_covariates
-        )
-        future_covariates = (
-            [future_covariates]
-            if isinstance(future_covariates, TimeSeries)
-            else future_covariates
-        )
+        # guarantee that all inputs are either list of TimeSeries or None
+        series = series2seq(series)
+        past_covariates = series2seq(past_covariates)
+        future_covariates = series2seq(future_covariates)
 
         self._verify_static_covariates(series[0].static_covariates)
+
         # encoders are set when calling fit(), but not when calling fit_from_dataset()
+        # additionally, do not generate encodings when covariates were loaded as they already
+        # contain the encodings
         if self.encoders is not None and self.encoders.encoding_available:
-            past_covariates, future_covariates = self.encoders.encode_inference(
+            past_covariates, future_covariates = self.generate_predict_encodings(
                 n=n,
-                target=series,
-                past_covariate=past_covariates,
-                future_covariate=future_covariates,
+                series=series,
+                past_covariates=past_covariates,
+                future_covariates=future_covariates,
             )
 
+        if past_covariates is None and self.past_covariate_series is not None:
+            past_covariates = series2seq(self.past_covariate_series)
+        if future_covariates is None and self.future_covariate_series is not None:
+            future_covariates = series2seq(self.future_covariate_series)
+
+        super().predict(n, series, past_covariates, future_covariates)
+
         dataset = self._build_inference_dataset(
             target=series,
             n=n,
@@ -1648,6 +1575,7 @@ class PastCovariatesTorchModel(TorchForecastingModel, ABC):
             input_chunk_length=self.input_chunk_length,
             output_chunk_length=self.output_chunk_length,
             max_samples_per_ts=max_samples_per_ts,
+            use_static_covariates=self._supports_static_covariates(),
         )
 
     def _build_inference_dataset(
@@ -1669,6 +1597,7 @@ class PastCovariatesTorchModel(TorchForecastingModel, ABC):
             n=n,
             input_chunk_length=self.input_chunk_length,
             output_chunk_length=self.output_chunk_length,
+            use_static_covariates=self._supports_static_covariates(),
         )
 
     def _verify_train_dataset_type(self, train_dataset: TrainingDataset):
@@ -1723,6 +1652,7 @@ class FutureCovariatesTorchModel(TorchForecastingModel, ABC):
             input_chunk_length=self.input_chunk_length,
             output_chunk_length=self.output_chunk_length,
             max_samples_per_ts=max_samples_per_ts,
+            use_static_covariates=self._supports_static_covariates(),
         )
 
     def _build_inference_dataset(
@@ -1742,6 +1672,7 @@ class FutureCovariatesTorchModel(TorchForecastingModel, ABC):
             covariates=future_covariates,
             n=n,
             input_chunk_length=self.input_chunk_length,
+            use_static_covariates=self._supports_static_covariates(),
         )
 
     def _verify_train_dataset_type(self, train_dataset: TrainingDataset):
@@ -1792,6 +1723,7 @@ class DualCovariatesTorchModel(TorchForecastingModel, ABC):
             input_chunk_length=self.input_chunk_length,
             output_chunk_length=self.output_chunk_length,
             max_samples_per_ts=max_samples_per_ts,
+            use_static_covariates=self._supports_static_covariates(),
         )
 
     def _build_inference_dataset(
@@ -1808,6 +1740,7 @@ class DualCovariatesTorchModel(TorchForecastingModel, ABC):
             n=n,
             input_chunk_length=self.input_chunk_length,
             output_chunk_length=self.output_chunk_length,
+            use_static_covariates=self._supports_static_covariates(),
         )
 
     def _verify_train_dataset_type(self, train_dataset: TrainingDataset):
@@ -1856,6 +1789,7 @@ class MixedCovariatesTorchModel(TorchForecastingModel, ABC):
             input_chunk_length=self.input_chunk_length,
             output_chunk_length=self.output_chunk_length,
             max_samples_per_ts=max_samples_per_ts,
+            use_static_covariates=self._supports_static_covariates(),
         )
 
     def _build_inference_dataset(
@@ -1873,6 +1807,7 @@ class MixedCovariatesTorchModel(TorchForecastingModel, ABC):
             n=n,
             input_chunk_length=self.input_chunk_length,
             output_chunk_length=self.output_chunk_length,
+            use_static_covariates=self._supports_static_covariates(),
         )
 
     def _verify_train_dataset_type(self, train_dataset: TrainingDataset):
@@ -1918,6 +1853,7 @@ class SplitCovariatesTorchModel(TorchForecastingModel, ABC):
             input_chunk_length=self.input_chunk_length,
             output_chunk_length=self.output_chunk_length,
             max_samples_per_ts=max_samples_per_ts,
+            use_static_covariates=self._supports_static_covariates(),
         )
 
     def _build_inference_dataset(
@@ -1935,6 +1871,7 @@ class SplitCovariatesTorchModel(TorchForecastingModel, ABC):
             n=n,
             input_chunk_length=self.input_chunk_length,
             output_chunk_length=self.output_chunk_length,
+            use_static_covariates=self._supports_static_covariates(),
         )
 
     def _verify_train_dataset_type(self, train_dataset: TrainingDataset):
