@@ -7,7 +7,6 @@ import numpy as np
 import pandas as pd
 from sklearn.ensemble import HistGradientBoostingRegressor, RandomForestRegressor
 from sklearn.linear_model import LinearRegression
-from sklearn.multioutput import MultiOutputRegressor
 
 import darts
 from darts import TimeSeries
@@ -25,6 +24,9 @@ from darts.tests.base_test_class import DartsBaseTestClass
 from darts.utils import timeseries_generation as tg
 from darts.utils.data.encoders import FutureCyclicEncoder, PastDatetimeAttributeEncoder
 
+# from sklearn.multioutput import MultiOutputRegressor
+from darts.utils.multioutput import MultiOutputRegressor
+
 logger = get_logger(__name__)
 
 
@@ -557,10 +559,7 @@ class RegressionModelsTestCase(DartsBaseTestClass):
 
             # while it should work with n = 1
             prediction = model_instance.predict(n=1)
-            self.assertTrue(
-                len(prediction) == 1,
-                f"Expected length 1, found {len(prediction)} instead",
-            )
+            self.assertEqual(len(prediction), 1)
 
     def test_fit(self):
         for model in self.models:
@@ -664,6 +663,29 @@ class RegressionModelsTestCase(DartsBaseTestClass):
             self.multivariate_multiseries_accuracies,
         )
 
+    def test_min_train_series_length(self):
+        model = LightGBMModel(lags=4)
+        min_train_series_length_expected = (
+            -model.lags["target"][0] + model.output_chunk_length + 1
+        )
+        self.assertEqual(
+            min_train_series_length_expected, model.min_train_series_length
+        )
+        model = CatBoostModel(lags=2)
+        min_train_series_length_expected = (
+            -model.lags["target"][0] + model.output_chunk_length + 1
+        )
+        self.assertEqual(
+            min_train_series_length_expected, model.min_train_series_length
+        )
+        model = LightGBMModel(lags=[-4, -3, -2])
+        min_train_series_length_expected = (
+            -model.lags["target"][0] + model.output_chunk_length + 1
+        )
+        self.assertEqual(
+            min_train_series_length_expected, model.min_train_series_length
+        )
+
     def test_historical_forecast(self):
         model = self.models[1](lags=5)
         result = model.historical_forecasts(
@@ -708,7 +730,7 @@ class RegressionModelsTestCase(DartsBaseTestClass):
         self.assertEqual(len(result), 21)
 
     def test_multioutput_wrapper(self):
-        lags = 12
+        lags = 4
         models = [
             (RegressionModel(lags=lags), True),
             (RegressionModel(lags=lags, model=LinearRegression()), True),
@@ -724,10 +746,28 @@ class RegressionModelsTestCase(DartsBaseTestClass):
             if supports_multioutput_natively:
                 self.assertFalse(isinstance(model.model, MultiOutputRegressor))
             else:
-                self.assertTrue(isinstance(model.model, MultiOutputRegressor))
+                self.assertIsInstance(model.model, MultiOutputRegressor)
+
+    def test_multioutput_validation(self):
+
+        lags = 4
+
+        models = [
+            LightGBMModel(lags=lags, output_chunk_length=1),
+            LightGBMModel(lags=lags, output_chunk_length=2),
+            CatBoostModel(lags=lags, output_chunk_length=1),
+            CatBoostModel(lags=lags, output_chunk_length=2),
+        ]
+
+        train, val = self.sine_univariate1.split_after(0.6)
+
+        for model in models:
+            model.fit(series=train, val_series=val)
+            if model.output_chunk_length > 1:
+                self.assertIsInstance(model.model, MultiOutputRegressor)
 
     def test_regression_model(self):
-        lags = 12
+        lags = 4
         models = [
             RegressionModel(lags=lags),
             RegressionModel(lags=lags, model=LinearRegression()),
@@ -841,7 +881,7 @@ class RegressionModelsTestCase(DartsBaseTestClass):
             inter_reduction=np.mean,
         )
 
-        self.assertTrue(error_past_only > error_both)
+        self.assertGreater(error_past_only, error_both)
         # test 2: with both covariates, 2 TS should learn more than one (with little noise)
         model = RegressionModel(
             lags=3, lags_past_covariates=5, lags_future_covariates=(5, 0)
@@ -863,7 +903,7 @@ class RegressionModelsTestCase(DartsBaseTestClass):
             inter_reduction=np.mean,
         )
 
-        self.assertTrue(error_both > error_both_multi_ts)
+        self.assertGreater(error_both, error_both_multi_ts)
 
     def test_only_future_covariates(self):
 
@@ -975,6 +1015,40 @@ class RegressionModelsTestCase(DartsBaseTestClass):
         assert lgb_fit_patch.call_args[1]["eval_set"] is not None
         assert lgb_fit_patch.call_args[1]["early_stopping_rounds"] == 2
 
+    def test_integer_indexed_series(self):
+        values_target = np.random.rand(30)
+        values_past_cov = np.random.rand(30)
+        values_future_cov = np.random.rand(30)
+
+        idx1 = pd.RangeIndex(start=0, stop=30, step=1)
+        idx2 = pd.RangeIndex(start=10, stop=70, step=2)
+
+        preds = []
+
+        for idx in [idx1, idx2]:
+            target = TimeSeries.from_times_and_values(idx, values_target)
+            past_cov = TimeSeries.from_times_and_values(idx, values_past_cov)
+            future_cov = TimeSeries.from_times_and_values(idx, values_future_cov)
+
+            train, _ = target[:20], target[20:]
+
+            model = LinearRegressionModel(
+                lags=[-2, -1], lags_past_covariates=[-2, -1], lags_future_covariates=[0]
+            )
+            model.fit(
+                series=train, past_covariates=past_cov, future_covariates=future_cov
+            )
+
+            preds.append(model.predict(n=10))
+
+        # the predicted values should not depend on the time axis
+        np.testing.assert_equal(preds[0].values(), preds[1].values())
+
+        # the time axis returned by the second model should be as expected
+        self.assertTrue(
+            all(preds[1].time_index == pd.RangeIndex(start=50, stop=70, step=2))
+        )
+
     def test_encoders(self):
         max_past_lag = -4
         max_future_lag = 4
@@ -1038,9 +1112,9 @@ class RegressionModelsTestCase(DartsBaseTestClass):
                 [model_pc_valid1, model_fc_valid1, model_mixed_valid1], examples
             ):
                 covariates = covariates_examples[ex]
-                # don't pass covariates, let them be generated by encoders
+                # don't pass covariates, let them be generated by encoders. Test single target series input
                 model_copy = copy.deepcopy(model)
-                model_copy.fit(target_series)
+                model_copy.fit(target_series[0])
                 assert model_copy.encoders.encoding_available
                 self.helper_test_encoders_settings(model_copy, ex)
 
